APP_NAME = 'countries_plus'
default_app_config = 'countries_plus.apps.DefaultConfig'
__version__ = '1.3.2'
